==> haskell-annotated-wl-pprint-0.7.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
key:                  annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  efefde626898605b1b9623ac0bda3e45
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-9.2.8/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-annotated-wl-pprint
hs-libraries:         HSannotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
depends:              base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-annotated-wl-pprint-0.7.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-annotated-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 annotated-wl-pprint
version:              0.7.0
visibility:           public
id:                   annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
key:                  annotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
license:              BSD-3-Clause
maintainer:           david@davidchristiansen.dk
author:               Daan Leijen, David Raymond Christiansen
homepage:             https://github.com/david-christiansen/annotated-wl-pprint
synopsis:             The Wadler/Leijen Pretty Printer, with annotation support
description:
    This is a modified version of wl-pprint, which was based on Wadler'\''s
    paper "A Prettier  Printer".  See the haddocks for full info.  This
    version allows the library user to annotate the text with semantic
    information, which can later be rendered in a variety of ways.

category:             Text
abi:                  1de9caae083b38d8d8b52888988392a9
exposed:              True
exposed-modules:      Text.PrettyPrint.Annotated.Leijen
import-dirs:          /usr/lib/ghc-9.4.8/site-local/annotated-wl-pprint-0.7.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/annotated-wl-pprint-0.7.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/annotated-wl-pprint-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-annotated-wl-pprint
hs-libraries:         HSannotated-wl-pprint-0.7.0-Bbb9GOQJoVZEpSwInbNN3i
depends:              base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-annotated-wl-pprint/html/annotated-wl-pprint.haddock

haddock-html:         /usr/share/doc/haskell-annotated-wl-pprint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
